==> tine20-allinone_2020.08.8.tar.bz2: Tasks/js/Tasks-lang-hu-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: hu\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""

]
, "Task, Tasks"
: [
  "Feladat"
 ,"Feladatok"

]
, "Percent"
: "Százalék"

, "Completed"
: "Teljesítve"

, "Due"
: "Esedékes"

, "Class"
: ""

, "Description"
: "Leírás"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Szervező"

, "Priority"
: "Prioritás"

, "Status, Status"
: [
  "Állapot"
 ,"Állapot"

]
, "Lead"
: "Ügylet"

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Meg kell adnod egy lejárati időt, mert riasztás van beállítva!"

, "Summary"
: "Összegzés"

, "Due date"
: "Lejárati idő"

, "Add Responsible ..."
: "Felelős hozzáadása..."

, "Notes"
: "Megjegyzések"

, "Enter description..."
: "Leírás megadása..."

, "Percentage"
: "Százalék"

, "Tasks"
: "Feladatok"

, "to do list, to do lists"
: [
  "teendő lista"
 ,"teendő listák"

]
, "to do lists"
: "teendő listák"

, "Quick Search"
: ""

, "Due Date"
: "Lejárati idő"

, "Responsible"
: "Felelős"

, "Last Modified Time"
: "Utolsó módosítás ideje"

, "Last Modified By"
: "Utoljára módosította"

, "Creation Time"
: "Készítés ideje"

, "Created By"
: "Készítette"

, "New Task"
: "Új feladat"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Biztosan törlöd a kiválasztott feladatot?"
 ,"Biztosan törlöd a kiválasztott feladatokat?"

]
, "Attachments"
: ""

, "Tags"
: "Címkék"

, "Lead name"
: ""

, "Add a task..."
: "Feladat hozzáadása..."

, "All my tasks"
: "Minden feladatom"

, "Default Favorite"
: "Alapértelmezett kedvenc"

, "The default favorite which is loaded on Tasks startup"
: "Alapértelmezett kedvenc, ami a Feladatok indításakor betöltődik"

, "Default Task List"
: "Alap Feladat Lista"

, "The default task list to create new tasks in."
: "Az alapértelmezett feladat lista amiben az új feladatokat létrehozom."

, "Tasks status available"
: "Feladat állapot elérhető"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Lehetséges feladat állapot. Kérlek jegyezd meg, hogy a további résztvevő állapot hatással lehet másik Feladat rendszerre exportáláskor vagy szinkronizáláskor."

, "No response"
: "Nincs válasz"

, "Cancelled"
: "Lemondva"

, "In process"
: "Folyamatban"

, "Task priorities available"
: "Feladat sürgősség elérhető"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Lehetséges feladat sürgősség. Kérlek jegyezd meg, hogy a további sürgősségek hatással lehetnek más Feladat rendszerekre exportálás vagy szinkronizálás esetén."

, "low"
: "alacsony"

, "normal"
: "normál"

, "high"
: "magas"

, "urgent"
: "sürgős"

, "manage shared task lists"
: "megosztott feladatalisták kezelése"

, "Create new shared tasks lists"
: "Új megosztott feladatlisták készítése"

, "manage shared tasks favorites"
: "kedvenc megosztott feladatok kezelése"

, "Create or update shared tasks favorites"
: "Kedvenc megosztott feladatok készítése vagy frissítése"

, "%s's personal tasks"
: "%s személyes feladatok"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Minden feladat a feladatlistámon"

, "My open tasks"
: "Nyitott feladataim"

, "My open tasks this week"
: "Nyitott feladataim erre a hétre"

, "All tasks for me"
: "Minden feladataim"

, "All tasks that I am responsible for"
: "Minden feladat amiért felelős vagyok"

, "Last modified by me"
: "Utoljára módosítottam"

, "All tasks that I have last modified"
: "Minden feladat amit utoljára én módosítottam"

, "Tasks without responsible"
: "Feladatok felelős nélkül"

, "GENDER_Task"
: ""

, "Task"
: "Feladat"

, "Status"
: "Állapot"

, "to do list"
: "teendő lista"

, "Do you really want to delete the selected task?"
: "Biztosan törlöd a kiválasztott feladatot?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-hu-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nLanguage: hu\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Meg kell adnod egy lejárati időt, mert riasztás van beállítva!"

, "Summary"
: "Összegzés"

, "Due date"
: "Lejárati idő"

, "Priority"
: "Prioritás"

, "Organizer"
: "Szervező"

, "Add Responsible ..."
: "Felelős hozzáadása..."

, "Notes"
: "Megjegyzések"

, "Enter description..."
: "Leírás megadása..."

, "Percentage"
: "Százalék"

, "Status, Status"
: [
  "Állapot"
 ,"Állapot"

]
, "Completed"
: "Teljesítve"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Biztosan törlöd a kiválasztott feladatot?"
 ,"Biztosan törlöd a kiválasztott feladatokat?"

]
, "Attachments"
: ""

, "Tags"
: "Címkék"

, "Lead name"
: ""

, "Add a task..."
: "Feladat hozzáadása..."

, "Due Date"
: "Lejárati idő"

, "Percent"
: "Százalék"

, "Responsible"
: "Felelős"

, "Task, Tasks"
: [
  "Feladat"
 ,"Feladatok"

]
, "Tasks"
: "Feladatok"

, "to do list, to do lists"
: [
  "teendő lista"
 ,"teendő listák"

]
, "to do lists"
: "teendő listák"

, "Quick Search"
: ""

, "Last Modified Time"
: "Utolsó módosítás ideje"

, "Last Modified By"
: "Utoljára módosította"

, "Creation Time"
: "Készítés ideje"

, "Created By"
: "Készítette"

, "New Task"
: "Új feladat"

, "All my tasks"
: "Minden feladatom"

, "Default Favorite"
: "Alapértelmezett kedvenc"

, "The default favorite which is loaded on Tasks startup"
: "Alapértelmezett kedvenc, ami a Feladatok indításakor betöltődik"

, "Default Task List"
: "Alap Feladat Lista"

, "The default task list to create new tasks in."
: "Az alapértelmezett feladat lista amiben az új feladatokat létrehozom."

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: "Feladat állapot elérhető"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Lehetséges feladat állapot. Kérlek jegyezd meg, hogy a további résztvevő állapot hatással lehet másik Feladat rendszerre exportáláskor vagy szinkronizáláskor."

, "No response"
: "Nincs válasz"

, "Cancelled"
: "Lemondva"

, "In process"
: "Folyamatban"

, "Task priorities available"
: "Feladat sürgősség elérhető"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Lehetséges feladat sürgősség. Kérlek jegyezd meg, hogy a további sürgősségek hatással lehetnek más Feladat rendszerekre exportálás vagy szinkronizálás esetén."

, "low"
: "alacsony"

, "normal"
: "normál"

, "high"
: "magas"

, "urgent"
: "sürgős"

, "%s's personal tasks"
: "%s személyes feladatok"

, "GENDER_Task"
: ""

, "Due"
: "Esedékes"

, "Class"
: ""

, "Description"
: "Leírás"

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: "Ügylet"

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Minden feladat a feladatlistámon"

, "My open tasks"
: "Nyitott feladataim"

, "My open tasks this week"
: "Nyitott feladataim erre a hétre"

, "All tasks for me"
: "Minden feladataim"

, "All tasks that I am responsible for"
: "Minden feladat amiért felelős vagyok"

, "Last modified by me"
: "Utoljára módosítottam"

, "All tasks that I have last modified"
: "Minden feladat amit utoljára én módosítottam"

, "Tasks without responsible"
: "Feladatok felelős nélkül"

, "manage shared task lists"
: "megosztott feladatalisták kezelése"

, "Create new shared tasks lists"
: "Új megosztott feladatlisták készítése"

, "manage shared tasks favorites"
: "kedvenc megosztott feladatok kezelése"

, "Create or update shared tasks favorites"
: "Kedvenc megosztott feladatok készítése vagy frissítése"

, "Status"
: "Állapot"

, "Do you really want to delete the selected task?"
: "Biztosan törlöd a kiválasztott feladatot?"

, "Task"
: "Feladat"

, "to do list"
: "teendő lista"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
